ewa.ply.yacc

Package ewa :: Package ply :: Module yacc |
[hide private]
[frames] | no frames]

# Module yacc

source code

Version: 3.3

Classes | [hide private]
| PlyLogger
| NullLogger
| YaccError
| YaccSymbol
| YaccProduction
| LRParser
| Production
| MiniProduction
| LRItem
| GrammarError
| Grammar
| VersionError
| LRTable
| LALRError
| LRGeneratedTable
| ParserReflect

Functions | [hide private]
func_code(f) | source code
load_ply_lex() | source code
format_result(r) | source code
format_stack_entry(r) | source code
rightmost_terminal(symbols, terminals) | source code
digraph(X, R, FP) | source code
traverse(x, N, stack, F, X, R, FP) | source code
get_caller_module_dict(levels) | source code
parse_grammar(doc, file, line) | source code
yacc(method=`'``LALR``'`, debug=1, module=None, tabmodule=`'``parsetab``'`, start=None, check_recursion=1, optimize=0, write_tables=1, debugfile=`'``parser.out``'`, outputdir=`'````'`, debuglog=None, errorlog=None, picklefile=None) | source code

Variables | [hide private]
| __tabversion__ = ``'``3.2``'``
| yaccdebug = `1`
| debug_file = ``'``parser.out``'``
| tab_module = ``'``parsetab``'``
| default_lr = ``'``LALR``'``
| error_count = `3`
| yaccdevel = `0`
| resultlimit = `40`
| pickle_protocol = `0`
| MAXINT = `2147483647`
| _is_identifier = `re.compile(r'^`[`a`-`zA`-`Z0`-`9_-`]``+`$')`
| __package__ = ``'``ewa.ply``'``